.. image:: ../../_static/CSAwesomeLogo.png
    :width: 350
    :align: center

Writing Classes
:::::::::::::::


Class Periods: 12-14

AP CSA Exam Weighting: 5-7.5%


.. toctree::
   :maxdepth: 3

   topic-5-1-parts-of-class.rst
   topic-5-2-writing-constructors.rst
   topic-5-3-comments-conditions.rst
   topic-5-4-accessor-methods.rst
   topic-5-5-mutator-methods.rst
   topic-5-6-writing-methods.rst
   topic-5-7-static-vars-methods.rst
   topic-5-8-scope-access.rst
   topic-5-9-this.rst
   topic-5-10-social-impacts.rst
   topic-5-11-summary.rst
   topic-parsons-practice.rst
   topic-toggle-problems.rst
   Exercises.rst
   midterm_unit5.rst
   FRQstepTracker.rst
   timeFRQ.rst
   APLine.rst
   CBLabs.rst
   community-challenge.rst

